// Define dimensions for the chart
var width = 600;
var height = 400;
var margin = { top: 20, right: 20, bottom: 50, left: 50 };

// Create SVG element
var svg = d3
  .select('#chart')
  .append('svg')
  .attr('width', width + margin.left + margin.right)
  .attr('height', height + margin.top + margin.bottom)
  .append('g')
  .attr(
    'transform',
    'translate(' + margin.left + ',' + margin.top + ')',
  );

d3.csv(
  'https://gist.githubusercontent.com/Pranayrajana/2f42f77298d3d967f43ed18eac30c42b/raw/e0ff4ddf9fc6a0c5ebd52c29de3fdbd175f373fe/Task%25209.csv',
)
  .then(function (data) {
    // Process data if needed
    data.forEach(function (d) {
      d.percent_democrat = +d.percent_democrat; // Convert to number if necessary
      // Add more processing if required
    });

    var xScale = d3
      .scaleBand()
      .domain(
        data.map(function (d) {
          return d.state;
        }),
      )
      .range([0, width])
      .padding(0.1);

    var yScale = d3
      .scaleLinear()
      .domain([
        0,
        d3.max(data, function (d) {
          return d.percent_democrat;
        }),
      ])
      .nice()
      .range([height, 0]);

    var area = d3
      .area()
      .x(function (d) {
        return xScale(d.state) + xScale.bandwidth() / 2;
      })
      .y0(height)
      .y1(function (d) {
        return yScale(d.percent_democrat);
      });

    svg
      .append('path')
      .datum(data)
      .attr('fill', 'steelblue')
      .attr('d', area);

    svg
      .append('g')
      .attr('class', 'x-axis')
      .attr('transform', 'translate(0,' + height + ')')
      .call(d3.axisBottom(xScale))
      .selectAll('text')
      .style('text-anchor', 'end')
      .attr('dx', '-.8em')
      .attr('dy', '-.55em')
      .attr('transform', 'rotate(-90)');

    svg
      .append('g')
      .attr('class', 'y-axis')
      .call(d3.axisLeft(yScale));

    svg
      .append('text')
      .attr('class', 'x-axis-label')
      .attr('x', width / 2)
      .attr('y', height + margin.bottom)
      .style('text-anchor', 'middle')
      .text('State');

    svg
      .append('text')
      .attr('class', 'y-axis-label')
      .attr('transform', 'rotate(-90)')
      .attr('x', -height / 2)
      .attr('y', -margin.left)
      .attr('dy', '1em')
      .style('text-anchor', 'middle')
      .text('Percent Democrat');

    svg
      .append('text')
      .attr('class', 'chart-title')
      .attr('x', width / 2)
      .attr('y', -margin.top)
      .attr('text-anchor', 'middle')
      .text('Percent Democrat by State');
  })
  .catch(function (error) {
    console.log(error);
  });
